==> crm-commom-vo-1.1.2.release.jar: com/biz/crm/nebular/mdm/PageVo.java <==
package com.biz.crm.nebular.mdm;

import com.bizunited.platform.common.vo.FormInstanceUuidVo;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.io.Serializable;

/**
 * @Description:
 * @Author: zhangyuzhu
 * @Date: 2020/8/27 10:35
 **/
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class PageVo extends FormInstanceUuidVo implements Serializable {
    private static final long serialVersionUID = 1L;
//    /**
//     * 业务表数据对应的表单实例编号
//     */
//    @SaturnColumn(description="表单实例编号" , nullable=false , length=256 , unique=true , insertable=true , updatable=false)
//    private String formInstanceId;

    /**
     * 每页数据的数量
     */
    private Integer pageSize=25;

    /**
     * 页码
     */
    private Integer pageNum=0;

    /**
     * 全选所有
     * @return
     */
    private String selectAllFlag;

//    public String getFormInstanceId() {
//        return formInstanceId;
//    }
//
//    public void setFormInstanceId(String formInstanceId) {
//        this.formInstanceId = formInstanceId;
//    }

    public String getSelectAllFlag() {
        return selectAllFlag;
    }

    public void setSelectAllFlag(String selectAllFlag) {
        this.selectAllFlag = selectAllFlag;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getPageNum() {
        return pageNum;
    }

    public void setPageNum(Integer pageNum) {
        this.pageNum = pageNum;
    }
}

==> crm-commom-vo-1.3.0.6.104.release.jar: com/biz/crm/nebular/mdm/PageVo.java <==
package com.biz.crm.nebular.mdm;

import com.bizunited.platform.common.vo.UuidVo;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.io.Serializable;

/**
 * @Description:
 * @Author: zhangyuzhu
 * @Date: 2020/8/27 10:35
 **/
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@JsonIgnoreProperties(ignoreUnknown = true)
public class PageVo extends UuidVo implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 每页数据的数量
     */
    private Integer pageSize=25;

    /**
     * 页码
     */
    private Integer pageNum=0;

    /**
     * 全选所有
     * @return
     */
    private String selectAllFlag;

    /**是否查询总页数*/
    @JsonIgnore
    private Boolean searchCount;


    public String getSelectAllFlag() {
        return selectAllFlag;
    }

    public void setSelectAllFlag(String selectAllFlag) {
        this.selectAllFlag = selectAllFlag;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getPageNum() {
        return pageNum;
    }

    public void setPageNum(Integer pageNum) {
        this.pageNum = pageNum;
    }

    public Boolean getSearchCount() {
        return searchCount;
    }

    public void setSearchCount(Boolean searchCount) {
        this.searchCount = searchCount;
    }
}
